ProgramFlags

Struct ProgramFlags 

pub struct ProgramFlags(/* private fields */);

Implementations

Source

impl ProgramFlags

pub const None: Self

pub const Read: Self

pub const Exec: Self

pub const Write: Self

pub const Mask: Self

pub fn any(self, bits: Self) -> bool

Returns true if any of the bits are set

pub fn all(self, bits: Self) -> bool

Returns true if all of the bits are set